#!/bin/bash

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

	if ! [ -f "$batch" ]; then
		echo "$batch not found"
		return 1
	fi

	srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
	dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
	diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
	envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

set -e

export OSGEO4W_MAINTAINER=JuergenFischer
export OSGEO4W_REP=$(cygpath -aw /tmp/rep)

for a in ${ARCHS:-x86 x86_64}; do
	echo "ARCH:$a"
	case "$a" in
	x86)
		export O4W_ROOT=/c/OSGeo4W
		;;
	x86_64)
		export O4W_ROOT=/c/OSGeo4W64
		;;
	esac

	for py in ${PYVERSIONS:-2.7 3.7}; do
		echo "PY:$py"
		(
			fetchenv $O4W_ROOT/bin/o4w_env.bat || true

			if [[ "$py" =~ "3." ]]; then
				fetchenv $O4W_ROOT/bin/py3_env.bat || true
				fetchenv $O4W_ROOT/bin/qt5_env.bat || true
			fi

			for p in "$@"; do
				echo " PKG: $a/$py/$p"
				python pip2o4w.py $p
			done
		)
	done
done
